@@ -1,5 +1,9 @@
 #ifndef MODULE_TOOLBOX
 #define MODULE_TOOLBOX
+#ifdef __cplusplus
+extern "C"
+{
+#endif
 /*****************************************************************************/
 /*  MODULE NAME:  ToolBox.h                             MODULE TYPE:  (dat)  */
 /*****************************************************************************/
@@ -79,7 +83,15 @@ typedef  Z_longword         *Z_longwordptr;
 #undef  TRUE
 #define TRUE        (0==0)
 
-typedef enum { false = FALSE , true = TRUE } boolean;
+#ifdef __cplusplus
+    typedef bool boolean;
+#else
+    #ifdef MACOS_TRADITIONAL
+        #define boolean Boolean
+    #else
+        typedef enum { false = FALSE, true = TRUE } boolean;
+    #endif
+#endif
 
 #define and         &&      /* logical (boolean) operators: lower case */
 #define or          ||
@@ -104,11 +116,13 @@ typedef enum { false = FALSE , true = TRUE } boolean;
 /*****************************************************************************/
 
 /*****************************************************************************/
-/*  VERSION:  5.3                                                            */
+/*  VERSION:  5.5                                                            */
 /*****************************************************************************/
 /*  VERSION HISTORY:                                                         */
 /*****************************************************************************/
 /*                                                                           */
+/*    Version 5.5   03.10.04  Added compiler directives for C++.             */
+/*    Version 5.4   08.09.02  Added conditional changes for MacOS/MacPerl.   */
 /*    Version 5.3   12.05.98  Completed history.                             */
 /*    Version 5.0   01.03.98  "Definitions.h" -> "ToolBox.h".                */
 /*    Version 4.0   24.03.97  "lib_defs.h" -> "Definitions.h".               */
@@ -125,10 +139,6 @@ typedef enum { false = FALSE , true = TRUE } boolean;
 /*****************************************************************************/
 /*                                                                           */
 /*    Steffen Beyer                                                          */
-/*    Ainmillerstr. 5 / App. 513                                             */
-/*    D-80801 Munich                                                         */
-/*    Germany                                                                */
-/*                                                                           */
 /*    mailto:sb@engelschall.com                                              */
 /*    http://www.engelschall.com/u/sb/download/                              */
 /*                                                                           */
@@ -136,7 +146,7 @@ typedef enum { false = FALSE , true = TRUE } boolean;
 /*  COPYRIGHT:                                                               */
 /*****************************************************************************/
 /*                                                                           */
-/*    Copyright (c) 1995, 1996, 1997, 1998, 1999 by Steffen Beyer.           */
+/*    Copyright (c) 1995 - 2009 by Steffen Beyer.                            */
 /*    All rights reserved.                                                   */
 /*                                                                           */
 /*****************************************************************************/
@@ -157,8 +167,10 @@ typedef enum { false = FALSE , true = TRUE } boolean;
 /*    License along with this library; if not, write to the                  */
 /*    Free Software Foundation, Inc.,                                        */
 /*    59 Temple Place, Suite 330, Boston, MA 02111-1307 USA                  */
-/*                                                                           */
 /*    or download a copy from ftp://ftp.gnu.org/pub/gnu/COPYING.LIB-2.0      */
 /*                                                                           */
 /*****************************************************************************/
+#ifdef __cplusplus
+}
+#endif
 #endif
